[−][src]Struct twilight_embed_builder::author::EmbedAuthorBuilder
Create an embed author with a builder.
This can be passed into EmbedBuilder::author.
Implementations
impl EmbedAuthorBuilder[src]
pub const NAME_LENGTH_LIMIT: usize[src]
The maximum number of UTF-16 code points that can be in an author name.
This is used by name.
pub fn new() -> Self[src]
Create a new default embed author builder.
#[must_use = "should be used as part of an embed builder"]pub fn build(self) -> EmbedAuthor[src]
Build into an embed author.
pub fn icon_url(self, image_source: ImageSource) -> Self[src]
Add an author icon.
pub fn name(self, name: impl Into<String>) -> Result<Self, EmbedAuthorNameError>[src]
The author's name.
Refer to NAME_LENGTH_LIMIT for the maximum number of UTF-16
code points that can be in a description.
Errors
Returns EmbedAuthorNameError::Empty if the provided name is empty.
Returns EmbedAuthorNameError::TooLong if the provided name is longer
than the maximum number of code points.
pub fn url(self, url: impl Into<String>) -> Self[src]
The author's url.