#[non_exhaustive]pub enum EmbedErrorType {
Show 16 variants
AuthorNameEmpty {
name: String,
},
AuthorNameTooLong {
name: String,
},
ColorNotRgb {
color: u32,
},
ColorZero,
DescriptionEmpty {
description: String,
},
DescriptionTooLong {
description: String,
},
FieldNameEmpty {
name: String,
value: String,
},
FieldNameTooLong {
name: String,
value: String,
},
FieldValueEmpty {
name: String,
value: String,
},
FieldValueTooLong {
name: String,
value: String,
},
FooterTextEmpty {
text: String,
},
FooterTextTooLong {
text: String,
},
TitleEmpty {
title: String,
},
TitleTooLong {
title: String,
},
TotalContentTooLarge {
length: usize,
},
TooManyFields {
fields: Vec<EmbedField>,
},
}use twilight_util::builder::embed
Type of EmbedError that occurred.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
AuthorNameEmpty
use twilight_util::builder::embed
Name is empty.
Fields
AuthorNameTooLong
use twilight_util::builder::embed
Name is longer than 256 UTF-16 code points.
ColorNotRgb
use twilight_util::builder::embed
Color was larger than a valid RGB hexadecimal value.
Fields
ColorZero
use twilight_util::builder::embed
Color was 0. The value would be thrown out by Discord and is equivalent to null.
DescriptionEmpty
use twilight_util::builder::embed
Description is empty.
Fields
DescriptionTooLong
use twilight_util::builder::embed
Description is longer than 4096 UTF-16 code points.
Fields
FieldNameEmpty
use twilight_util::builder::embed
Name is empty.
Fields
FieldNameTooLong
use twilight_util::builder::embed
Name is longer than 256 UTF-16 code points.
Fields
FieldValueEmpty
use twilight_util::builder::embed
Value is empty.
Fields
FieldValueTooLong
use twilight_util::builder::embed
Value is longer than 1024 UTF-16 code points.
Fields
use twilight_util::builder::embed
Footer text is empty.
use twilight_util::builder::embed
Footer text is longer than 2048 UTF-16 code points.
TitleEmpty
use twilight_util::builder::embed
Title is empty.
Fields
TitleTooLong
use twilight_util::builder::embed
Title is longer than 256 UTF-16 code points.
TotalContentTooLarge
use twilight_util::builder::embed
The total content of the embed is too large.
Refer to EmbedBuilder::EMBED_LENGTH_LIMIT for more information about
what goes into this limit.
Fields
TooManyFields
use twilight_util::builder::embed
Too many fields were provided.
Refer to EmbedBuilder::EMBED_FIELD_LIMIT for more information about
what the limit is.
Fields
fields: Vec<EmbedField>use twilight_util::builder::embed
The provided fields.